#
# PySNMP MIB module URI-TC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/URI-TC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:32:35 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, SingleValueConstraint, ValueRangeConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsUnion")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( MibIdentifier, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Counter64, Unsigned32, Integer32, Bits, iso, Counter32, ObjectIdentity, IpAddress, TimeTicks, mib_2, NotificationType, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibIdentifier", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter64", "Unsigned32", "Integer32", "Bits", "iso", "Counter32", "ObjectIdentity", "IpAddress", "TimeTicks", "mib-2", "NotificationType", "ModuleIdentity")
( DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention")
uriTcMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 164)).setRevisions(("2007-09-10 00:00",))
if mibBuilder.loadTexts: uriTcMIB.setLastUpdated('200709100000Z')
if mibBuilder.loadTexts: uriTcMIB.setOrganization('IETF Operations and Management (OPS) Area')
if mibBuilder.loadTexts: uriTcMIB.setContactInfo('EMail: ops-area@ietf.org\n                  Home page: http://www.ops.ietf.org/')
if mibBuilder.loadTexts: uriTcMIB.setDescription('This MIB module defines textual conventions for\n            representing URIs, as defined by RFC 3986 STD 66.')
class Uri(OctetString, TextualConvention):
    displayHint = '1a'

class Uri255(OctetString, TextualConvention):
    displayHint = '255a'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,255)

class Uri1024(OctetString, TextualConvention):
    displayHint = '1024a'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,1024)

mibBuilder.exportSymbols("URI-TC-MIB", PYSNMP_MODULE_ID=uriTcMIB, Uri=Uri, Uri255=Uri255, Uri1024=Uri1024, uriTcMIB=uriTcMIB)



#
# PySNMP MIB module IPV6-MLD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IPV6-MLD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:18:42 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ValueSizeConstraint")
( InterfaceIndexOrZero, InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndexOrZero", "InterfaceIndex")
( InetAddressIPv6, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressIPv6")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( ModuleIdentity, TimeTicks, Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, mib_2, iso, Gauge32, Bits, Counter64, NotificationType, MibIdentifier, Unsigned32, Counter32, ObjectIdentity, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "ModuleIdentity", "TimeTicks", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "mib-2", "iso", "Gauge32", "Bits", "Counter64", "NotificationType", "MibIdentifier", "Unsigned32", "Counter32", "ObjectIdentity", "IpAddress")
( RowStatus, TruthValue, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "RowStatus", "TruthValue", "DisplayString", "TextualConvention")
mldMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 91)).setRevisions(("2001-01-25 00:00",))
if mibBuilder.loadTexts: mldMIB.setLastUpdated('200101250000Z')
if mibBuilder.loadTexts: mldMIB.setOrganization('IETF IPNGWG Working Group.')
if mibBuilder.loadTexts: mldMIB.setContactInfo(' Brian Haberman\n                 Nortel Networks\n                 4309 Emperor Blvd.\n                 Durham, NC  27703\n                 USA\n\n                 Phone: +1 919 992 4439\n                 e-mail: haberman@nortelnetworks.com')
if mibBuilder.loadTexts: mldMIB.setDescription('The MIB module for MLD Management.')
mldMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 91, 1))
mldInterfaceTable = MibTable((1, 3, 6, 1, 2, 1, 91, 1, 1), )
if mibBuilder.loadTexts: mldInterfaceTable.setDescription('The (conceptual) table listing the interfaces on which\n                MLD is enabled.')
mldInterfaceEntry = MibTableRow((1, 3, 6, 1, 2, 1, 91, 1, 1, 1), ).setIndexNames((0, "IPV6-MLD-MIB", "mldInterfaceIfIndex"))
if mibBuilder.loadTexts: mldInterfaceEntry.setDescription('An entry (conceptual row) representing an interface on\n               which MLD is enabled.')
mldInterfaceIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: mldInterfaceIfIndex.setDescription('The internetwork-layer interface value of the interface\n               for which MLD is enabled.')
mldInterfaceQueryInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 2), Unsigned32().clone(125)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceQueryInterval.setDescription('The frequency at which MLD Host-Query packets are\n               transmitted on this interface.')
mldInterfaceStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceStatus.setDescription('The activation of a row enables MLD on the interface.\n                The destruction of a row disables MLD on the interface.')
mldInterfaceVersion = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 4), Unsigned32().clone(1)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceVersion.setDescription('The version of MLD which is running on this interface.\n                This object is a place holder to allow for new versions\n                of MLD to be introduced.  Version 1 of MLD is defined\n                in RFC 2710.')
mldInterfaceQuerier = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 5), InetAddressIPv6().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldInterfaceQuerier.setDescription('The address of the MLD Querier on the IPv6 subnet to\n                which this interface is attached.')
mldInterfaceQueryMaxResponseDelay = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 6), Unsigned32().clone(10)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceQueryMaxResponseDelay.setDescription('The maximum query response time advertised in MLD\n               queries on this interface.')
mldInterfaceJoins = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldInterfaceJoins.setDescription('The number of times a group membership has been added on\n               this interface; that is, the number of times an entry for\n               this interface has been added to the Cache Table.  This\n               object gives an indication of the amount of MLD activity\n               over time.')
mldInterfaceGroups = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 8), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldInterfaceGroups.setDescription('The current number of entries for this interface in the\n               Cache Table.')
mldInterfaceRobustness = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 9), Unsigned32().clone(2)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceRobustness.setDescription('The Robustness Variable allows tuning for the expected\n               packet loss on a subnet.  If a subnet is expected to be\n               lossy, the Robustness Variable may be increased.  MLD is\n               robust to (Robustness Variable-1) packet losses.  The\n               discussion of the Robustness Variable is in Section 7.1\n               of RFC 2710.')
mldInterfaceLastListenQueryIntvl = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 10), Unsigned32().clone(1)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceLastListenQueryIntvl.setDescription('The Last Member Query Interval is the Max Response\n                Delay inserted into Group-Specific Queries sent in\n                response to Leave Group messages, and is also the amount\n                of time between Group-Specific Query messages.  This\n                value may be tuned to modify the leave latency of the\n                network.  A reduced value results in reduced time to\n                detect the loss of the last member of a group.')
mldInterfaceProxyIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 11), InterfaceIndexOrZero()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldInterfaceProxyIfIndex.setDescription('Some devices implement a form of MLD proxying whereby\n                memberships learned on the interface represented by this\n                row, cause MLD Multicast Listener Reports to be sent on\n                the internetwork-layer interface identified by this\n                object.  Such a device would implement mldRouterMIBGroup\n                only on its router interfaces (those interfaces with\n                non-zero mldInterfaceProxyIfIndex).  Typically, the\n                value of this object is 0, indicating that no proxying\n                is being done.')
mldInterfaceQuerierUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 12), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldInterfaceQuerierUpTime.setDescription('The time since mldInterfaceQuerier was last changed.')
mldInterfaceQuerierExpiryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 1, 1, 13), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldInterfaceQuerierExpiryTime.setDescription('The time remaining before the Other Querier Present\n               Timer expires.  If the local system is the querier,\n               the value of this object is zero.')
mldCacheTable = MibTable((1, 3, 6, 1, 2, 1, 91, 1, 2), )
if mibBuilder.loadTexts: mldCacheTable.setDescription('The (conceptual) table listing the IPv6 multicast\n                groups for which there are members on a particular\n                interface.')
mldCacheEntry = MibTableRow((1, 3, 6, 1, 2, 1, 91, 1, 2, 1), ).setIndexNames((0, "IPV6-MLD-MIB", "mldCacheAddress"), (0, "IPV6-MLD-MIB", "mldCacheIfIndex"))
if mibBuilder.loadTexts: mldCacheEntry.setDescription('An entry (conceptual row) in the mldCacheTable.')
mldCacheAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 1), InetAddressIPv6().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16))
if mibBuilder.loadTexts: mldCacheAddress.setDescription('The IPv6 multicast group address for which this entry\n               contains information.')
mldCacheIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 2), InterfaceIndex())
if mibBuilder.loadTexts: mldCacheIfIndex.setDescription('The internetwork-layer interface for which this entry\n                contains information for an IPv6 multicast group\n                address.')
mldCacheSelf = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 3), TruthValue().clone('true')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldCacheSelf.setDescription('An indication of whether the local system is a member of\n               this group address on this interface.')
mldCacheLastReporter = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 4), InetAddressIPv6().subtype(subtypeSpec=ValueSizeConstraint(16,16)).setFixedLength(16)).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldCacheLastReporter.setDescription('The IPv6 address of the source of the last membership\n                report received for this IPv6 Multicast group address on\n                this interface.  If no membership report has been\n                received, this object has the value 0::0.')
mldCacheUpTime = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 5), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldCacheUpTime.setDescription('The time elapsed since this entry was created.')
mldCacheExpiryTime = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 6), TimeTicks()).setMaxAccess("readonly")
if mibBuilder.loadTexts: mldCacheExpiryTime.setDescription('The minimum amount of time remaining before this entry\n                will be aged out.  A value of 0 indicates that the entry\n                is only present because mldCacheSelf is true and that if\n                the router left the group, this entry would be aged out\n                immediately.  Note that some implementations may process\n                Membership Reports from the local system in the same way\n                as reports from other hosts, so a value of 0 is not\n                required.')
mldCacheStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 91, 1, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: mldCacheStatus.setDescription('The status of this row, by which new entries may be\n               created, or existing entries deleted from this table.')
mldMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 91, 2))
mldMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 91, 2, 1))
mldMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 91, 2, 2))
mldHostMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 91, 2, 1, 1)).setObjects(*(("IPV6-MLD-MIB", "mldBaseMIBGroup"), ("IPV6-MLD-MIB", "mldHostMIBGroup"),))
if mibBuilder.loadTexts: mldHostMIBCompliance.setDescription('The compliance statement for hosts running MLD and\n               implementing the MLD MIB.')
mldRouterMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 91, 2, 1, 2)).setObjects(*(("IPV6-MLD-MIB", "mldBaseMIBGroup"), ("IPV6-MLD-MIB", "mldRouterMIBGroup"),))
if mibBuilder.loadTexts: mldRouterMIBCompliance.setDescription('The compliance statement for routers running MLD and\n               implementing the MLD MIB.')
mldBaseMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 91, 2, 2, 1)).setObjects(*(("IPV6-MLD-MIB", "mldCacheSelf"), ("IPV6-MLD-MIB", "mldCacheStatus"), ("IPV6-MLD-MIB", "mldInterfaceStatus"),))
if mibBuilder.loadTexts: mldBaseMIBGroup.setDescription('The basic collection of objects providing management of\n               MLD.  The mldBaseMIBGroup is designed to allow for the\n               manager creation and deletion of MLD cache entries.')
mldRouterMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 91, 2, 2, 2)).setObjects(*(("IPV6-MLD-MIB", "mldCacheUpTime"), ("IPV6-MLD-MIB", "mldCacheExpiryTime"), ("IPV6-MLD-MIB", "mldInterfaceQueryInterval"), ("IPV6-MLD-MIB", "mldInterfaceJoins"), ("IPV6-MLD-MIB", "mldInterfaceGroups"), ("IPV6-MLD-MIB", "mldCacheLastReporter"), ("IPV6-MLD-MIB", "mldInterfaceQuerierUpTime"), ("IPV6-MLD-MIB", "mldInterfaceQuerierExpiryTime"), ("IPV6-MLD-MIB", "mldInterfaceQuerier"), ("IPV6-MLD-MIB", "mldInterfaceVersion"), ("IPV6-MLD-MIB", "mldInterfaceQueryMaxResponseDelay"), ("IPV6-MLD-MIB", "mldInterfaceRobustness"), ("IPV6-MLD-MIB", "mldInterfaceLastListenQueryIntvl"),))
if mibBuilder.loadTexts: mldRouterMIBGroup.setDescription('A collection of additional objects for management of MLD\n               in routers.')
mldHostMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 91, 2, 2, 3)).setObjects(*(("IPV6-MLD-MIB", "mldInterfaceQuerier"),))
if mibBuilder.loadTexts: mldHostMIBGroup.setDescription('A collection of additional objects for management of MLD\n               in hosts.')
mldProxyMIBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 91, 2, 2, 4)).setObjects(*(("IPV6-MLD-MIB", "mldInterfaceProxyIfIndex"),))
if mibBuilder.loadTexts: mldProxyMIBGroup.setDescription('A collection of additional objects for management of MLD\n               proxy devices.')
mibBuilder.exportSymbols("IPV6-MLD-MIB", mldInterfaceRobustness=mldInterfaceRobustness, mldInterfaceProxyIfIndex=mldInterfaceProxyIfIndex, mldMIBObjects=mldMIBObjects, mldCacheStatus=mldCacheStatus, mldInterfaceQuerierExpiryTime=mldInterfaceQuerierExpiryTime, mldInterfaceStatus=mldInterfaceStatus, mldInterfaceQuerier=mldInterfaceQuerier, mldCacheAddress=mldCacheAddress, mldInterfaceIfIndex=mldInterfaceIfIndex, mldInterfaceVersion=mldInterfaceVersion, mldMIBGroups=mldMIBGroups, mldInterfaceLastListenQueryIntvl=mldInterfaceLastListenQueryIntvl, mldHostMIBCompliance=mldHostMIBCompliance, mldInterfaceGroups=mldInterfaceGroups, mldCacheTable=mldCacheTable, mldInterfaceQueryMaxResponseDelay=mldInterfaceQueryMaxResponseDelay, mldInterfaceQueryInterval=mldInterfaceQueryInterval, mldCacheLastReporter=mldCacheLastReporter, mldRouterMIBCompliance=mldRouterMIBCompliance, mldCacheEntry=mldCacheEntry, mldMIBCompliances=mldMIBCompliances, mldInterfaceJoins=mldInterfaceJoins, PYSNMP_MODULE_ID=mldMIB, mldCacheSelf=mldCacheSelf, mldHostMIBGroup=mldHostMIBGroup, mldCacheIfIndex=mldCacheIfIndex, mldProxyMIBGroup=mldProxyMIBGroup, mldRouterMIBGroup=mldRouterMIBGroup, mldInterfaceEntry=mldInterfaceEntry, mldCacheUpTime=mldCacheUpTime, mldBaseMIBGroup=mldBaseMIBGroup, mldInterfaceTable=mldInterfaceTable, mldCacheExpiryTime=mldCacheExpiryTime, mldMIB=mldMIB, mldInterfaceQuerierUpTime=mldInterfaceQuerierUpTime, mldMIBConformance=mldMIBConformance)



#
# PySNMP MIB module ITU-ALARM-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ITU-ALARM-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:19:29 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( alarmListName, alarmActiveIndex, alarmActiveDateAndTime, alarmModelIndex, ) = mibBuilder.importSymbols("ALARM-MIB", "alarmListName", "alarmActiveIndex", "alarmActiveDateAndTime", "alarmModelIndex")
( Integer, OctetString, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "Integer", "OctetString", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( IANAItuProbableCause, IANAItuEventType, ) = mibBuilder.importSymbols("IANA-ITU-ALARM-TC-MIB", "IANAItuProbableCause", "IANAItuEventType")
( ItuPerceivedSeverity, ItuTrendIndication, ) = mibBuilder.importSymbols("ITU-ALARM-TC-MIB", "ItuPerceivedSeverity", "ItuTrendIndication")
( ZeroBasedCounter32, ) = mibBuilder.importSymbols("RMON2-MIB", "ZeroBasedCounter32")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( MibScalar, MibTable, MibTableRow, MibTableColumn, ObjectIdentity, Gauge32, Counter64, IpAddress, NotificationType, Unsigned32, ModuleIdentity, MibIdentifier, Bits, mib_2, TimeTicks, iso, Integer32, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ObjectIdentity", "Gauge32", "Counter64", "IpAddress", "NotificationType", "Unsigned32", "ModuleIdentity", "MibIdentifier", "Bits", "mib-2", "TimeTicks", "iso", "Integer32", "Counter32")
( AutonomousType, TextualConvention, RowPointer, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "AutonomousType", "TextualConvention", "RowPointer", "DisplayString")
ituAlarmMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 121)).setRevisions(("2004-09-09 00:00",))
if mibBuilder.loadTexts: ituAlarmMIB.setLastUpdated('200409090000Z')
if mibBuilder.loadTexts: ituAlarmMIB.setOrganization('IETF Distributed Management Working Group')
if mibBuilder.loadTexts: ituAlarmMIB.setContactInfo('WG EMail: disman@ietf.org\n           Subscribe: disman-request@ietf.org\n           http://www.ietf.org/html.charters/disman-charter.html\n\n           Chair:     Randy Presuhn\n                      randy_presuhn@mindspring.com\n\n           Editors:   Sharon Chisholm\n                      Nortel Networks\n                      PO Box 3511 Station C\n                      Ottawa, Ont.  K1Y 4H7\n                      Canada\n                      schishol@nortelnetworks.com\n\n                      Dan Romascanu\n                      Avaya\n                      Atidim Technology Park, Bldg. #3\n                      Tel Aviv, 61131\n\n                      Israel\n                      Tel: +972-3-645-8414\n                      Email: dromasca@avaya.com')
if mibBuilder.loadTexts: ituAlarmMIB.setDescription('The MIB module describes ITU Alarm information\n              as defined in ITU Recommendation M.3100 [M.3100],\n              X.733 [X.733] and X.736 [X.736].\n\n              Copyright (C) The Internet Society (2004).  The\n              initial version of this MIB module was published\n              in RFC 3877.  For full legal notices see the RFC\n              itself.  Supplementary information may be available on:\n              http://www.ietf.org/copyrights/ianamib.html')
ituAlarmObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 121, 1))
ituAlarmModel = MibIdentifier((1, 3, 6, 1, 2, 1, 121, 1, 1))
ituAlarmActive = MibIdentifier((1, 3, 6, 1, 2, 1, 121, 1, 2))
ituAlarmTable = MibTable((1, 3, 6, 1, 2, 1, 121, 1, 1, 1), )
if mibBuilder.loadTexts: ituAlarmTable.setDescription('A table of ITU Alarm information for possible alarms\n       on the system.')
ituAlarmEntry = MibTableRow((1, 3, 6, 1, 2, 1, 121, 1, 1, 1, 1), ).setIndexNames((0, "ALARM-MIB", "alarmListName"), (0, "ALARM-MIB", "alarmModelIndex"), (0, "ITU-ALARM-MIB", "ituAlarmPerceivedSeverity"))
if mibBuilder.loadTexts: ituAlarmEntry.setDescription('Entries appear in this table whenever an entry is created\n        in the alarmModelTable with a value of alarmModelState in\n        the range from 1 to 6.  Entries disappear from this table\n        whenever the corresponding entries are deleted from the\n        alarmModelTable, including in cases where those entries\n        have been deleted due to local system action.  The value of\n        alarmModelSpecificPointer has no effect on the creation\n        or deletion of entries in this table.  Values of\n        alarmModelState map to values of ituAlarmPerceivedSeverity\n        as follows:\n\n          alarmModelState -> ituAlarmPerceivedSeverity\n                 1        ->         clear (1)\n                 2        ->         indeterminate (2)\n                 3        ->         warning (6)\n                 4        ->         minor (5)\n                 5        ->         major (4)\n                 6        ->         critical (3)\n\n        All other values of alarmModelState MUST NOT appear\n        in this table.\n\n        This table MUST be persistent across system reboots.')
ituAlarmPerceivedSeverity = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 1, 1, 1, 1), ItuPerceivedSeverity())
if mibBuilder.loadTexts: ituAlarmPerceivedSeverity.setDescription('ITU perceived severity values.')
ituAlarmEventType = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 1, 1, 1, 2), IANAItuEventType()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ituAlarmEventType.setDescription('Represents the event type values for the alarms')
ituAlarmProbableCause = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 1, 1, 1, 3), IANAItuProbableCause()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ituAlarmProbableCause.setDescription('ITU probable cause values.')
ituAlarmAdditionalText = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 1, 1, 1, 4), SnmpAdminString()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ituAlarmAdditionalText.setDescription('Represents the additional text field for the alarm.')
ituAlarmGenericModel = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 1, 1, 1, 5), RowPointer()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ituAlarmGenericModel.setDescription('This object points to the corresponding\n    row in the alarmModelTable for this alarm severity.\n\n    This corresponding entry to alarmModelTable could also\n    be derived by performing the reverse of the mapping\n    from alarmModelState to ituAlarmPerceivedSeverity defined\n\n    in the description of ituAlarmEntry to determine the\n    appropriate { alarmListName, alarmModelIndex, alarmModelState }\n    for this { alarmListName, alarmModelIndex,\n    ituAlarmPerceivedSeverity }.')
ituAlarmActiveTable = MibTable((1, 3, 6, 1, 2, 1, 121, 1, 2, 1), )
if mibBuilder.loadTexts: ituAlarmActiveTable.setDescription('A table of ITU information for active alarms entries.')
ituAlarmActiveEntry = MibTableRow((1, 3, 6, 1, 2, 1, 121, 1, 2, 1, 1), ).setIndexNames((0, "ALARM-MIB", "alarmListName"), (0, "ALARM-MIB", "alarmActiveDateAndTime"), (0, "ALARM-MIB", "alarmActiveIndex"))
if mibBuilder.loadTexts: ituAlarmActiveEntry.setDescription('Entries appear in this table when alarms are active.  They\n       are removed when the alarm is no longer occurring.')
ituAlarmActiveTrendIndication = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 1, 1, 1), ItuTrendIndication()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveTrendIndication.setDescription('Represents the trend indication values for the alarms.')
ituAlarmActiveDetector = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 1, 1, 2), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveDetector.setDescription('Represents the SecurityAlarmDetector object.')
ituAlarmActiveServiceProvider = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 1, 1, 3), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveServiceProvider.setDescription('Represents the ServiceProvider object.')
ituAlarmActiveServiceUser = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 1, 1, 4), AutonomousType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveServiceUser.setDescription('Represents the ServiceUser object.')
ituAlarmActiveStatsTable = MibTable((1, 3, 6, 1, 2, 1, 121, 1, 2, 2), )
if mibBuilder.loadTexts: ituAlarmActiveStatsTable.setDescription('This table represents the ITU alarm statistics\n         information.')
ituAlarmActiveStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1), ).setIndexNames((0, "ALARM-MIB", "alarmListName"))
if mibBuilder.loadTexts: ituAlarmActiveStatsEntry.setDescription('Statistics on the current active ITU alarms.')
ituAlarmActiveStatsIndeterminateCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsIndeterminateCurrent.setDescription('A count of the current number of active alarms with a\n        ituAlarmPerceivedSeverity of indeterminate.')
ituAlarmActiveStatsCriticalCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 2), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsCriticalCurrent.setDescription('A count of the current number of active alarms with a\n        ituAlarmPerceivedSeverity of critical.')
ituAlarmActiveStatsMajorCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsMajorCurrent.setDescription('A count of the current number of active alarms with a\n\n        ituAlarmPerceivedSeverity of major.')
ituAlarmActiveStatsMinorCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 4), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsMinorCurrent.setDescription('A count of the current number of active alarms with a\n        ituAlarmPerceivedSeverity of minor.')
ituAlarmActiveStatsWarningCurrent = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsWarningCurrent.setDescription('A count of the current number of active alarms with a\n        ituAlarmPerceivedSeverity of warning.')
ituAlarmActiveStatsIndeterminates = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 6), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsIndeterminates.setDescription('A count of the total number of active alarms with a\n        ituAlarmPerceivedSeverity of indeterminate since system\n        restart.')
ituAlarmActiveStatsCriticals = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 7), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsCriticals.setDescription('A count of the total number of active alarms with a\n        ituAlarmPerceivedSeverity of critical since system restart.')
ituAlarmActiveStatsMajors = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 8), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsMajors.setDescription('A count of the total number of active alarms with a\n        ituAlarmPerceivedSeverity of major since system restart.')
ituAlarmActiveStatsMinors = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 9), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsMinors.setDescription('A count of the total number of active alarms with a\n        ituAlarmPerceivedSeverity of minor since system restart.')
ituAlarmActiveStatsWarnings = MibTableColumn((1, 3, 6, 1, 2, 1, 121, 1, 2, 2, 1, 10), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ituAlarmActiveStatsWarnings.setDescription('A count of the total number of active alarms with a\n        ituAlarmPerceivedSeverity of warning since system restart.')
ituAlarmConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 121, 2))
ituAlarmCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 121, 2, 1))
ituAlarmCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 121, 2, 1, 1)).setObjects(*(("ITU-ALARM-MIB", "ituAlarmGroup"), ("ITU-ALARM-MIB", "ituAlarmServiceUserGroup"), ("ITU-ALARM-MIB", "ituAlarmSecurityGroup"), ("ITU-ALARM-MIB", "ituAlarmStatisticsGroup"),))
if mibBuilder.loadTexts: ituAlarmCompliance.setDescription('The compliance statement for systems supporting\n          the ITU Alarm MIB.')
ituAlarmGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 121, 2, 2))
ituAlarmGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 121, 2, 2, 1)).setObjects(*(("ITU-ALARM-MIB", "ituAlarmEventType"), ("ITU-ALARM-MIB", "ituAlarmProbableCause"), ("ITU-ALARM-MIB", "ituAlarmGenericModel"),))
if mibBuilder.loadTexts: ituAlarmGroup.setDescription('ITU alarm details list group.')
ituAlarmServiceUserGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 121, 2, 2, 2)).setObjects(*(("ITU-ALARM-MIB", "ituAlarmAdditionalText"), ("ITU-ALARM-MIB", "ituAlarmActiveTrendIndication"),))
if mibBuilder.loadTexts: ituAlarmServiceUserGroup.setDescription('The use of these parameters is a service-user option.')
ituAlarmSecurityGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 121, 2, 2, 3)).setObjects(*(("ITU-ALARM-MIB", "ituAlarmActiveDetector"), ("ITU-ALARM-MIB", "ituAlarmActiveServiceProvider"), ("ITU-ALARM-MIB", "ituAlarmActiveServiceUser"),))
if mibBuilder.loadTexts: ituAlarmSecurityGroup.setDescription('Security Alarm Reporting Function')
ituAlarmStatisticsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 121, 2, 2, 4)).setObjects(*(("ITU-ALARM-MIB", "ituAlarmActiveStatsIndeterminateCurrent"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsCriticalCurrent"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsMajorCurrent"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsMinorCurrent"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsWarningCurrent"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsIndeterminates"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsCriticals"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsMajors"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsMinors"), ("ITU-ALARM-MIB", "ituAlarmActiveStatsWarnings"),))
if mibBuilder.loadTexts: ituAlarmStatisticsGroup.setDescription('ITU Active Alarm Statistics.')
mibBuilder.exportSymbols("ITU-ALARM-MIB", ituAlarmGroups=ituAlarmGroups, ituAlarmActiveTrendIndication=ituAlarmActiveTrendIndication, ituAlarmActive=ituAlarmActive, ituAlarmActiveStatsCriticals=ituAlarmActiveStatsCriticals, ituAlarmActiveStatsMajors=ituAlarmActiveStatsMajors, ituAlarmPerceivedSeverity=ituAlarmPerceivedSeverity, ituAlarmActiveServiceProvider=ituAlarmActiveServiceProvider, ituAlarmActiveStatsWarnings=ituAlarmActiveStatsWarnings, ituAlarmTable=ituAlarmTable, ituAlarmActiveStatsCriticalCurrent=ituAlarmActiveStatsCriticalCurrent, ituAlarmActiveStatsIndeterminates=ituAlarmActiveStatsIndeterminates, ituAlarmServiceUserGroup=ituAlarmServiceUserGroup, ituAlarmObjects=ituAlarmObjects, ituAlarmActiveEntry=ituAlarmActiveEntry, ituAlarmActiveStatsEntry=ituAlarmActiveStatsEntry, ituAlarmModel=ituAlarmModel, ituAlarmActiveStatsMajorCurrent=ituAlarmActiveStatsMajorCurrent, ituAlarmProbableCause=ituAlarmProbableCause, ituAlarmActiveStatsTable=ituAlarmActiveStatsTable, ituAlarmSecurityGroup=ituAlarmSecurityGroup, ituAlarmActiveStatsMinors=ituAlarmActiveStatsMinors, ituAlarmActiveDetector=ituAlarmActiveDetector, ituAlarmConformance=ituAlarmConformance, ituAlarmActiveStatsWarningCurrent=ituAlarmActiveStatsWarningCurrent, PYSNMP_MODULE_ID=ituAlarmMIB, ituAlarmActiveStatsMinorCurrent=ituAlarmActiveStatsMinorCurrent, ituAlarmActiveStatsIndeterminateCurrent=ituAlarmActiveStatsIndeterminateCurrent, ituAlarmActiveServiceUser=ituAlarmActiveServiceUser, ituAlarmStatisticsGroup=ituAlarmStatisticsGroup, ituAlarmGroup=ituAlarmGroup, ituAlarmCompliances=ituAlarmCompliances, ituAlarmMIB=ituAlarmMIB, ituAlarmAdditionalText=ituAlarmAdditionalText, ituAlarmCompliance=ituAlarmCompliance, ituAlarmActiveTable=ituAlarmActiveTable, ituAlarmGenericModel=ituAlarmGenericModel, ituAlarmEntry=ituAlarmEntry, ituAlarmEventType=ituAlarmEventType)



#
# PySNMP MIB module RTP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/RTP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:27:38 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ObjectGroup, ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "ModuleCompliance", "NotificationGroup")
( TimeTicks, Gauge32, Counter64, iso, NotificationType, ModuleIdentity, mib_2, ObjectIdentity, Unsigned32, Integer32, IpAddress, Counter32, Bits, MibIdentifier, MibScalar, MibTable, MibTableRow, MibTableColumn, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "Gauge32", "Counter64", "iso", "NotificationType", "ModuleIdentity", "mib-2", "ObjectIdentity", "Unsigned32", "Integer32", "IpAddress", "Counter32", "Bits", "MibIdentifier", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn")
( TextualConvention, DisplayString, TruthValue, TDomain, TimeStamp, TestAndIncr, RowStatus, TAddress, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TruthValue", "TDomain", "TimeStamp", "TestAndIncr", "RowStatus", "TAddress")
( Utf8String, ) = mibBuilder.importSymbols("SYSAPPL-MIB", "Utf8String")
rtpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 87)).setRevisions(("2000-10-02 00:00",))
if mibBuilder.loadTexts: rtpMIB.setLastUpdated('200010020000Z')
if mibBuilder.loadTexts: rtpMIB.setOrganization('IETF AVT Working Group\n    Email:   rem-conf@es.net')
if mibBuilder.loadTexts: rtpMIB.setContactInfo('Mark Baugher\n    Postal: Intel Corporation\n            2111 NE 25th Avenue\n            Hillsboro, OR   97124\n            United States\n    Tel:    +1 503 466 8406\n    Email:  mbaugher@passedge.com\n\n            Bill Strahm\n    Postal: Intel Corporation\n            2111 NE 25th Avenue\n            Hillsboro, OR   97124\n            United States\n    Tel:    +1 503 264 4632\n    Email:  bill.strahm@intel.com\n\n            Irina Suconick\n    Postal: Ennovate Networks\n            60 Codman Hill Rd.,\n            Boxboro, Ma 01719\n    Tel:    +1 781-505-2155\n    Email:  irina@ennovatenetworks.com')
if mibBuilder.loadTexts: rtpMIB.setDescription("The managed objects of RTP systems.  The MIB is\n        structured around three types of information.\n        1. General information about RTP sessions such\n           as the session address.\n        2. Information about RTP streams being sent to\n           an RTP session by a particular sender.\n        3. Information about RTP streams received on an\n           RTP session by a particular receiver from a\n           particular sender.\n         There are two types of RTP Systems, RTP hosts and\n         RTP monitors.  As described below, certain objects\n         are unique to a particular type of RTP System.   An\n         RTP host may also function as an RTP monitor.\n         Refer to RFC 1889, 'RTP: A Transport Protocol for\n         Real-Time Applications,' section 3.0, for definitions.")
rtpMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 87, 1))
rtpConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 87, 2))
rtpSessionNewIndex = MibScalar((1, 3, 6, 1, 2, 1, 87, 1, 1), TestAndIncr()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: rtpSessionNewIndex.setDescription("This  object  is  used  to  assign  values  to rtpSessionIndex\n       as described in 'Textual Conventions  for  SMIv2'.  For an RTP\n       system that supports the creation of rows, the  network manager\n       would read the  object,  and  then write the value back in\n       the Set that creates a new instance  of rtpSessionEntry.   If\n       the  Set  fails with the code 'inconsistentValue,' then the\n       process must be repeated; If the Set succeeds, then the object\n       is incremented, and the  new  instance  is created according to\n       the manager's directions.  However, if the RTP agent is not\n       acting as a monitor, only the RTP agent may create conceptual\n       rows in the RTP session table.")
rtpSessionInverseTable = MibTable((1, 3, 6, 1, 2, 1, 87, 1, 2), )
if mibBuilder.loadTexts: rtpSessionInverseTable.setDescription('Maps rtpSessionDomain, rtpSessionRemAddr, and rtpSessionLocAddr\n       TAddress pairs to one or more rtpSessionIndex values, each\n       describing a row in the rtpSessionTable.  This makes it possible\n       to retrieve the row(s) in the rtpSessionTable corresponding to a\n       given session without having to walk the entire (potentially\n       large) table.')
rtpSessionInverseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 87, 1, 2, 1), ).setIndexNames((0, "RTP-MIB", "rtpSessionDomain"), (0, "RTP-MIB", "rtpSessionRemAddr"), (0, "RTP-MIB", "rtpSessionLocAddr"), (0, "RTP-MIB", "rtpSessionIndex"))
if mibBuilder.loadTexts: rtpSessionInverseEntry.setDescription('Each entry corresponds to exactly one entry in the\n       rtpSessionTable - the entry containing the tuple,\n       rtpSessionDomain, rtpSessionRemAddr, rtpSessionLocAddr\n       and rtpSessionIndex.')
rtpSessionInverseStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 2, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionInverseStartTime.setDescription('The value of SysUpTime at the time that this row was\n       created.')
rtpSessionTable = MibTable((1, 3, 6, 1, 2, 1, 87, 1, 3), )
if mibBuilder.loadTexts: rtpSessionTable.setDescription("There's one entry in rtpSessionTable for each RTP session\n          on which packets are being sent, received, and/or\n          monitored.")
rtpSessionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 87, 1, 3, 1), ).setIndexNames((0, "RTP-MIB", "rtpSessionIndex"))
if mibBuilder.loadTexts: rtpSessionEntry.setDescription("Data in rtpSessionTable uniquely identify an RTP session.  A\n       host RTP agent MUST create a read-only row for each session to\n       which packets are being sent or received.  Rows MUST be created\n       by the RTP Agent at the start of a session when one or more\n       senders or receivers are observed.  Rows created by an RTP agent\n       MUST be deleted when the session is over and there are no\n       rtpRcvrEntry and no rtpSenderEntry for this session.  An RTP\n       session SHOULD be monitored to create management information on\n       all RTP streams being sent or received when the\n       rtpSessionMonitor has the TruthValue of 'true(1)'.  An RTP\n       monitor SHOULD permit row creation with the side effect of\n       causing the RTP System to join the multicast session for the\n       purposes of gathering management information  (additional\n       conceptual rows are created in the rtpRcvrTable and\n       rtpSenderTable).  Thus, rtpSessionTable rows SHOULD be created\n       for RTP session monitoring purposes.  Rows created by a\n       management application SHOULD be deleted via SNMP operations by\n       management applications.  Rows created by management operations\n       are deleted by management operations by setting\n       rtpSessionRowStatus to 'destroy(6)'.")
rtpSessionIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: rtpSessionIndex.setDescription('The index of the conceptual row which is for SNMP purposes\n       only and has no relation to any protocol value.  There is\n       no requirement that these rows are created or maintained\n       sequentially.')
rtpSessionDomain = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 2), TDomain()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rtpSessionDomain.setDescription("The transport-layer protocol used for sending or receiving\n       the stream of RTP data packets on this session.\n       Cannot be changed if rtpSessionRowStatus is 'active'.")
rtpSessionRemAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 3), TAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rtpSessionRemAddr.setDescription("The address to which RTP packets are sent by the RTP system.\n      In an IP multicast RTP session, this is the single address used\n      by all senders and receivers of RTP session data.  In a unicast\n      RTP session this is the unicast address of the remote RTP system.\n      'The destination address pair may be common for all participants,\n      as in the case of IP multicast, or may be different for each, as\n      in the case of individual unicast network address pairs.'  See\n      RFC 1889, 'RTP: A Transport Protocol for Real-Time Applications,'\n      sec. 3.  The transport service is identified by rtpSessionDomain.\n      For snmpUDPDomain, this is an IP address and even-numbered UDP\n      Port with the RTCP being sent on the next higher odd-numbered\n      port, see RFC 1889, sec. 5.")
rtpSessionLocAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 4), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionLocAddr.setDescription("The local address used by the RTP system.  In an IP multicast\n       RTP session, rtpSessionRemAddr will be the same IP multicast\n       address as rtpSessionLocAddr.  In a unicast RTP session,\n       rtpSessionRemAddr and rtpSessionLocAddr will have different\n       unicast addresses.  See RFC 1889, 'RTP: A Transport Protocol for\n       Real-Time Applications,' sec. 3.  The transport service is\n       identified by rtpSessionDomain.  For snmpUDPDomain, this is an IP\n       address and even-numbered UDP Port with the RTCP being sent on\n       the next higher odd-numbered port, see RFC 1889, sec. 5.")
rtpSessionIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 5), InterfaceIndex()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rtpSessionIfIndex.setDescription("The ifIndex value is set to the corresponding value\n      from IF-MIB (See RFC 2233, 'The Interfaces Group MIB using\n      SMIv2').  This is the interface that the RTP stream is being sent\n      to or received from, or in the case of an RTP Monitor the\n      interface that RTCP packets will be received on.  Cannot be\n      changed if rtpSessionRowStatus is 'active'.")
rtpSessionSenderJoins = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionSenderJoins.setDescription("The number of senders that have been observed to have\n       joined the session since this conceptual row was created\n       (rtpSessionStartTime).  A sender 'joins' an RTP\n       session by sending to it.  Senders that leave and then\n       re-join following an RTCP BYE (see RFC 1889, 'RTP: A\n       Transport Protocol for Real-Time Applications,' sec. 6.6)\n       or session timeout may be counted twice.  Every time a new\n       RTP sender is detected either using RTP or RTCP, this counter\n       is incremented.")
rtpSessionReceiverJoins = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionReceiverJoins.setDescription("The number of receivers that have been been observed to\n       have joined this session since this conceptual row was\n       created (rtpSessionStartTime).  A receiver 'joins' an RTP\n       session by sending RTCP Receiver Reports to the session.\n       Receivers that leave and then re-join following an RTCP BYE\n       (see RFC 1889, 'RTP: A Transport Protocol for Real-Time\n       Applications,' sec. 6.6) or session timeout may be counted\n       twice.")
rtpSessionByes = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionByes.setDescription("A count of RTCP BYE (see RFC 1889, 'RTP: A Transport\n       Protocol for Real-Time Applications,' sec. 6.6) messages\n       received by this entity.")
rtpSessionStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 9), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionStartTime.setDescription('The value of SysUpTime at the time that this row was\n       created.')
rtpSessionMonitor = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 10), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSessionMonitor.setDescription("Boolean, Set to 'true(1)' if remote senders or receivers in\n       addition to the local RTP System are to be monitored using RTCP.\n       RTP Monitors MUST initialize to 'true(1)' and RTP Hosts SHOULD\n       initialize this 'false(2)'.  Note that because 'host monitor'\n       systems are receiving RTCP from their remote participants they\n       MUST set this value to 'true(1)'.")
rtpSessionRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 3, 1, 11), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: rtpSessionRowStatus.setDescription("Value of 'active' when RTP or RTCP messages are being\n       sent or received by an RTP System.  A newly-created\n       conceptual row must have the all read-create objects\n       initialized before becoming 'active'.\n       A conceptual row that is in the 'notReady' or 'notInService'\n       state MAY be removed after 5  minutes.")
rtpSenderInverseTable = MibTable((1, 3, 6, 1, 2, 1, 87, 1, 4), )
if mibBuilder.loadTexts: rtpSenderInverseTable.setDescription('Maps rtpSenderAddr, rtpSessionIndex, to the rtpSenderSSRC\n       index of the rtpSenderTable.  This table allows management\n       applications to find entries sorted by rtpSenderAddr rather than\n       sorted by rtpSessionIndex.  Given the rtpSessionDomain and\n       rtpSenderAddr, a set of rtpSessionIndex and rtpSenderSSRC values\n       can be returned from a tree walk.  When rtpSessionIndex is\n       specified in the SNMP Get-Next operations, one or more\n       rtpSenderSSRC values may be returned.')
rtpSenderInverseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 87, 1, 4, 1), ).setIndexNames((0, "RTP-MIB", "rtpSessionDomain"), (0, "RTP-MIB", "rtpSenderAddr"), (0, "RTP-MIB", "rtpSessionIndex"), (0, "RTP-MIB", "rtpSenderSSRC"))
if mibBuilder.loadTexts: rtpSenderInverseEntry.setDescription('Each entry corresponds to exactly one entry in the\n       rtpSenderTable - the entry containing the index pair,\n       rtpSessionIndex, rtpSenderSSRC.')
rtpSenderInverseStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 4, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderInverseStartTime.setDescription('The value of SysUpTime at the time that this row was\n       created.')
rtpSenderTable = MibTable((1, 3, 6, 1, 2, 1, 87, 1, 5), )
if mibBuilder.loadTexts: rtpSenderTable.setDescription("Table of information about a sender or senders to an RTP\n       Session. RTP sending hosts MUST have an entry in this table\n       for each stream being sent.  RTP receiving hosts MAY have an\n       entry in this table for each sending stream being received by\n       this host.  RTP monitors MUST create an entry for each observed\n       sender to a multicast RTP Session as a side-effect when a\n       conceptual row in the rtpSessionTable is made 'active' by a\n       manager.")
rtpSenderEntry = MibTableRow((1, 3, 6, 1, 2, 1, 87, 1, 5, 1), ).setIndexNames((0, "RTP-MIB", "rtpSessionIndex"), (0, "RTP-MIB", "rtpSenderSSRC"))
if mibBuilder.loadTexts: rtpSenderEntry.setDescription("Each entry contains information from a single RTP Sender\n       Synchronization Source (SSRC, see RFC 1889 'RTP: A Transport\n       Protocol for Real-Time Applications' sec.6).  The session is\n       identified to the the SNMP entity by rtpSessionIndex.\n       Rows are removed by the RTP agent when a BYE is received\n       from the sender or when the sender times out (see RFC\n       1889, Sec. 6.2.1) or when the rtpSessionEntry is deleted.")
rtpSenderSSRC = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 1), Unsigned32())
if mibBuilder.loadTexts: rtpSenderSSRC.setDescription("The RTP SSRC, or synchronization source identifier of the\n       sender.  The RTP session address plus an SSRC uniquely\n       identify a sender to an RTP session (see RFC 1889, 'RTP: A\n       Transport Protocol for Real-Time Applications' sec.3).")
rtpSenderCNAME = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 2), Utf8String()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderCNAME.setDescription('The RTP canonical name of the sender.')
rtpSenderAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 3), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderAddr.setDescription('The unicast transport source address of the sender.  In the\n       case of an RTP Monitor this address is the address that the\n       sender is using to send its RTCP Sender Reports.')
rtpSenderPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 4), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderPackets.setDescription('Count of RTP packets sent by this sender, or observed by\n       an RTP monitor, since rtpSenderStartTime.')
rtpSenderOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 5), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderOctets.setDescription('Count of non-header RTP octets sent by this sender, or observed\n       by an RTP monitor, since rtpSenderStartTime.')
rtpSenderTool = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 6), Utf8String().subtype(subtypeSpec=ValueSizeConstraint(0,127))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderTool.setDescription('Name of the application program source of the stream.')
rtpSenderSRs = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderSRs.setDescription('A count of the number of RTCP Sender Reports that have\n       been sent from this sender, or observed if the RTP entity\n       is a monitor, since rtpSenderStartTime.')
rtpSenderSRTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 8), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderSRTime.setDescription('rtpSenderSRTime is the value of SysUpTime at the time that\n       the last SR was received from this sender, in the case of a\n       monitor or receiving host.  Or sent by this sender, in the\n       case of a sending host.')
rtpSenderPT = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,127))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderPT.setDescription("Payload type from the RTP header of the most recently received\n       RTP Packet (see RFC 1889, 'RTP: A Transport Protocol for\n       Real-Time Applications' sec. 5).")
rtpSenderStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 5, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpSenderStartTime.setDescription('The value of SysUpTime at the time that this row was\n       created.')
rtpRcvrInverseTable = MibTable((1, 3, 6, 1, 2, 1, 87, 1, 6), )
if mibBuilder.loadTexts: rtpRcvrInverseTable.setDescription('Maps rtpRcvrAddr and rtpSessionIndex to the rtpRcvrSRCSSRC and\n       rtpRcvrSSRC indexes of the rtpRcvrTable.  This table allows\n       management applications to find entries sorted by rtpRcvrAddr\n       rather than by rtpSessionIndex. Given rtpSessionDomain and\n       rtpRcvrAddr, a set of rtpSessionIndex, rtpRcvrSRCSSRC, and\n       rtpRcvrSSRC values can be returned from a tree walk.  When\n       rtpSessionIndex is specified in SNMP Get-Next operations, one or\n       more rtpRcvrSRCSSRC and rtpRcvrSSRC pairs may be returned.')
rtpRcvrInverseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 87, 1, 6, 1), ).setIndexNames((0, "RTP-MIB", "rtpSessionDomain"), (0, "RTP-MIB", "rtpRcvrAddr"), (0, "RTP-MIB", "rtpSessionIndex"), (0, "RTP-MIB", "rtpRcvrSRCSSRC"), (0, "RTP-MIB", "rtpRcvrSSRC"))
if mibBuilder.loadTexts: rtpRcvrInverseEntry.setDescription('Each entry corresponds to exactly one entry in the\n       rtpRcvrTable - the entry containing the index pair,\n       rtpSessionIndex, rtpRcvrSSRC.')
rtpRcvrInverseStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 6, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrInverseStartTime.setDescription('The value of SysUpTime at the time that this row was\n       created.')
rtpRcvrTable = MibTable((1, 3, 6, 1, 2, 1, 87, 1, 7), )
if mibBuilder.loadTexts: rtpRcvrTable.setDescription("Table of information about a receiver or receivers of RTP\n       session data. RTP hosts that receive RTP session packets\n       MUST create an entry in this table for that receiver/sender\n       pair.  RTP hosts that send RTP session packets MAY create\n       an entry in this table for each receiver to their stream\n       using RTCP feedback from the RTP group.  RTP monitors\n       create an entry for each observed RTP session receiver as\n       a side effect when a conceptual row in the rtpSessionTable\n       is made 'active' by a manager.")
rtpRcvrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 87, 1, 7, 1), ).setIndexNames((0, "RTP-MIB", "rtpSessionIndex"), (0, "RTP-MIB", "rtpRcvrSRCSSRC"), (0, "RTP-MIB", "rtpRcvrSSRC"))
if mibBuilder.loadTexts: rtpRcvrEntry.setDescription("Each entry contains information from a single RTP\n       Synchronization Source that is receiving packets from the\n       sender identified by rtpRcvrSRCSSRC (SSRC, see RFC 1889,\n       'RTP: A Transport Protocol for Real-Time Applications'\n       sec.6).  The session is identified to the the RTP Agent entity\n       by rtpSessionIndex.  Rows are removed by the RTP agent when\n       a BYE is received from the sender or when the sender times\n       out (see RFC 1889, Sec. 6.2.1) or when the rtpSessionEntry is\n       deleted.")
rtpRcvrSRCSSRC = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 1), Unsigned32())
if mibBuilder.loadTexts: rtpRcvrSRCSSRC.setDescription("The RTP SSRC, or synchronization source identifier of the\n       sender.  The RTP session address plus an SSRC uniquely\n       identify a sender or receiver of an RTP stream (see RFC\n       1889, 'RTP:  A Transport Protocol for Real-Time\n       Applications' sec.3).")
rtpRcvrSSRC = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 2), Unsigned32())
if mibBuilder.loadTexts: rtpRcvrSSRC.setDescription("The RTP SSRC, or synchronization source identifier of the\n       receiver.  The RTP session address plus an SSRC uniquely\n       identify a receiver of an RTP stream (see RFC 1889, 'RTP:\n       A Transport Protocol for Real-Time Applications' sec.3).")
rtpRcvrCNAME = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 3), Utf8String()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrCNAME.setDescription('The RTP canonical name of the receiver.')
rtpRcvrAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 4), TAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrAddr.setDescription('The unicast transport address on which the receiver is\n       receiving RTP packets and/or RTCP Receiver Reports.')
rtpRcvrRTT = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrRTT.setDescription("The round trip time measurement taken by the source of the\n       RTP stream based on the algorithm described on sec. 6 of\n       RFC 1889, 'RTP: A Transport Protocol for Real-Time\n       Applications.'  This algorithm can produce meaningful\n       results when the RTP agent has the same clock as the stream\n       sender (when the RTP monitor is also the sending host for the\n       particular receiver).  Otherwise, the entity should return\n       'noSuchInstance' in response to queries against rtpRcvrRTT.")
rtpRcvrLostPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 6), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrLostPackets.setDescription('A count of RTP  packets lost as observed by this receiver\n       since rtpRcvrStartTime.')
rtpRcvrJitter = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 7), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrJitter.setDescription("An estimate of delay variation as observed by this\n       receiver.  (see RFC 1889, 'RTP: A Transport Protocol\n       for Real-Time Applications' sec.6.3.1 and A.8).")
rtpRcvrTool = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 8), Utf8String().subtype(subtypeSpec=ValueSizeConstraint(0,127))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrTool.setDescription('Name of the application program source of the stream.')
rtpRcvrRRs = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrRRs.setDescription('A count of the number of RTCP Receiver Reports that have\n       been sent from this receiver, or observed if the RTP entity\n       is a monitor, since rtpRcvrStartTime.')
rtpRcvrRRTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrRRTime.setDescription('rtpRcvrRRTime is the value of SysUpTime at the time that the\n       last RTCP Receiver Report was received from this receiver, in\n       the case of a monitor or RR receiver (the RTP Sender).  It is\n       the  value of SysUpTime at the time that the last RR was sent by\n       this receiver in the case of an RTP receiver sending the RR.')
rtpRcvrPT = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,127))).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrPT.setDescription("Static or dynamic payload type from the RTP header (see\n       RFC 1889, 'RTP: A Transport Protocol for Real-Time\n       Applications' sec. 5).")
rtpRcvrPackets = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 12), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrPackets.setDescription('Count of RTP packets received by this RTP host receiver\n       since rtpRcvrStartTime.')
rtpRcvrOctets = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 13), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrOctets.setDescription('Count of non-header RTP octets received by this receiving RTP\n       host since rtpRcvrStartTime.')
rtpRcvrStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 87, 1, 7, 1, 14), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: rtpRcvrStartTime.setDescription('The value of SysUpTime at the time that this row was\n       created.')
rtpGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 87, 2, 1))
rtpSystemGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 87, 2, 1, 1)).setObjects(*(("RTP-MIB", "rtpSessionDomain"), ("RTP-MIB", "rtpSessionRemAddr"), ("RTP-MIB", "rtpSessionIfIndex"), ("RTP-MIB", "rtpSessionSenderJoins"), ("RTP-MIB", "rtpSessionReceiverJoins"), ("RTP-MIB", "rtpSessionStartTime"), ("RTP-MIB", "rtpSessionByes"), ("RTP-MIB", "rtpSessionMonitor"), ("RTP-MIB", "rtpSenderCNAME"), ("RTP-MIB", "rtpSenderAddr"), ("RTP-MIB", "rtpSenderPackets"), ("RTP-MIB", "rtpSenderOctets"), ("RTP-MIB", "rtpSenderTool"), ("RTP-MIB", "rtpSenderSRs"), ("RTP-MIB", "rtpSenderSRTime"), ("RTP-MIB", "rtpSenderStartTime"), ("RTP-MIB", "rtpRcvrCNAME"), ("RTP-MIB", "rtpRcvrAddr"), ("RTP-MIB", "rtpRcvrLostPackets"), ("RTP-MIB", "rtpRcvrJitter"), ("RTP-MIB", "rtpRcvrTool"), ("RTP-MIB", "rtpRcvrRRs"), ("RTP-MIB", "rtpRcvrRRTime"), ("RTP-MIB", "rtpRcvrStartTime"),))
if mibBuilder.loadTexts: rtpSystemGroup.setDescription('Objects available to all RTP Systems.')
rtpHostGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 87, 2, 1, 2)).setObjects(*(("RTP-MIB", "rtpSessionLocAddr"), ("RTP-MIB", "rtpSenderPT"), ("RTP-MIB", "rtpRcvrPT"), ("RTP-MIB", "rtpRcvrRTT"), ("RTP-MIB", "rtpRcvrOctets"), ("RTP-MIB", "rtpRcvrPackets"),))
if mibBuilder.loadTexts: rtpHostGroup.setDescription('Objects that are available to RTP Host systems, but may not\n            be available to RTP Monitor systems.')
rtpMonitorGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 87, 2, 1, 3)).setObjects(*(("RTP-MIB", "rtpSessionNewIndex"), ("RTP-MIB", "rtpSessionRowStatus"),))
if mibBuilder.loadTexts: rtpMonitorGroup.setDescription('Objects used to create rows in the RTP Session Table.  These\n        objects are not needed if the system does not create rows.')
rtpInverseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 87, 2, 1, 4)).setObjects(*(("RTP-MIB", "rtpSessionInverseStartTime"), ("RTP-MIB", "rtpSenderInverseStartTime"), ("RTP-MIB", "rtpRcvrInverseStartTime"),))
if mibBuilder.loadTexts: rtpInverseGroup.setDescription('Objects used in the Inverse Lookup Tables.')
rtpCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 87, 2, 2))
rtpHostCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 87, 2, 2, 1)).setObjects(*(("RTP-MIB", "rtpSystemGroup"), ("RTP-MIB", "rtpHostGroup"), ("RTP-MIB", "rtpMonitorGroup"), ("RTP-MIB", "rtpInverseGroup"),))
if mibBuilder.loadTexts: rtpHostCompliance.setDescription('Host implementations MUST comply.')
rtpMonitorCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 87, 2, 2, 2)).setObjects(*(("RTP-MIB", "rtpSystemGroup"), ("RTP-MIB", "rtpMonitorGroup"), ("RTP-MIB", "rtpHostGroup"), ("RTP-MIB", "rtpInverseGroup"),))
if mibBuilder.loadTexts: rtpMonitorCompliance.setDescription('Monitor implementations must comply.  RTP Monitors are not\n          required to support creation or deletion.')
mibBuilder.exportSymbols("RTP-MIB", rtpRcvrStartTime=rtpRcvrStartTime, rtpRcvrJitter=rtpRcvrJitter, rtpSenderTool=rtpSenderTool, rtpSenderSSRC=rtpSenderSSRC, rtpSessionLocAddr=rtpSessionLocAddr, rtpRcvrInverseStartTime=rtpRcvrInverseStartTime, rtpSessionNewIndex=rtpSessionNewIndex, rtpSessionRemAddr=rtpSessionRemAddr, rtpRcvrOctets=rtpRcvrOctets, rtpSessionInverseStartTime=rtpSessionInverseStartTime, rtpRcvrPackets=rtpRcvrPackets, rtpConformance=rtpConformance, rtpSenderPT=rtpSenderPT, rtpSessionMonitor=rtpSessionMonitor, rtpMonitorCompliance=rtpMonitorCompliance, rtpRcvrLostPackets=rtpRcvrLostPackets, rtpRcvrRRs=rtpRcvrRRs, rtpSessionInverseEntry=rtpSessionInverseEntry, rtpInverseGroup=rtpInverseGroup, rtpSenderSRTime=rtpSenderSRTime, rtpSessionTable=rtpSessionTable, rtpRcvrSSRC=rtpRcvrSSRC, rtpSessionIndex=rtpSessionIndex, rtpSenderAddr=rtpSenderAddr, rtpRcvrRRTime=rtpRcvrRRTime, rtpSenderOctets=rtpSenderOctets, rtpRcvrTable=rtpRcvrTable, rtpMIBObjects=rtpMIBObjects, rtpSessionStartTime=rtpSessionStartTime, rtpSenderInverseStartTime=rtpSenderInverseStartTime, rtpSenderStartTime=rtpSenderStartTime, rtpRcvrTool=rtpRcvrTool, rtpSenderPackets=rtpSenderPackets, rtpRcvrInverseEntry=rtpRcvrInverseEntry, rtpRcvrCNAME=rtpRcvrCNAME, rtpSenderCNAME=rtpSenderCNAME, rtpSessionRowStatus=rtpSessionRowStatus, rtpRcvrSRCSSRC=rtpRcvrSRCSSRC, rtpSessionDomain=rtpSessionDomain, rtpSessionInverseTable=rtpSessionInverseTable, rtpSessionByes=rtpSessionByes, rtpRcvrAddr=rtpRcvrAddr, rtpSessionSenderJoins=rtpSessionSenderJoins, rtpSenderSRs=rtpSenderSRs, rtpRcvrPT=rtpRcvrPT, rtpCompliances=rtpCompliances, rtpSenderEntry=rtpSenderEntry, PYSNMP_MODULE_ID=rtpMIB, rtpRcvrInverseTable=rtpRcvrInverseTable, rtpHostGroup=rtpHostGroup, rtpMonitorGroup=rtpMonitorGroup, rtpRcvrRTT=rtpRcvrRTT, rtpSessionReceiverJoins=rtpSessionReceiverJoins, rtpSenderInverseTable=rtpSenderInverseTable, rtpRcvrEntry=rtpRcvrEntry, rtpSessionIfIndex=rtpSessionIfIndex, rtpGroups=rtpGroups, rtpMIB=rtpMIB, rtpHostCompliance=rtpHostCompliance, rtpSenderTable=rtpSenderTable, rtpSenderInverseEntry=rtpSenderInverseEntry, rtpSessionEntry=rtpSessionEntry, rtpSystemGroup=rtpSystemGroup)



#
# PySNMP MIB module DIRECTORY-SERVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DIRECTORY-SERVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:07:50 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, ConstraintsIntersection, SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "ConstraintsIntersection", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint")
( applIndex, URLString, DistinguishedName, ) = mibBuilder.importSymbols("NETWORK-SERVICES-MIB", "applIndex", "URLString", "DistinguishedName")
( ZeroBasedCounter32, ) = mibBuilder.importSymbols("RMON2-MIB", "ZeroBasedCounter32")
( NotificationGroup, ObjectGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ObjectGroup", "ModuleCompliance")
( TimeTicks, Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, Integer32, NotificationType, ModuleIdentity, Counter32, mib_2, IpAddress, ObjectIdentity, Counter64, MibIdentifier, iso, Unsigned32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "Integer32", "NotificationType", "ModuleIdentity", "Counter32", "mib-2", "IpAddress", "ObjectIdentity", "Counter64", "MibIdentifier", "iso", "Unsigned32")
( TextualConvention, DisplayString, TimeStamp, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TimeStamp")
dsMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 66)).setRevisions(("1999-06-07 00:00", "1993-11-25 00:00",))
if mibBuilder.loadTexts: dsMIB.setLastUpdated('9906070000Z')
if mibBuilder.loadTexts: dsMIB.setOrganization('IETF Mail and Directory Management Working\n                     Group')
if mibBuilder.loadTexts: dsMIB.setContactInfo('                      Glenn Mansfield\n                     Postal: Cyber Solutions Inc.\n                             6-6-3, Minami Yoshinari\n                             Aoba-ku, Sendai, Japan 989-3204.\n\n                        Tel: +81-22-303-4012\n                        Fax: +81-22-303-4015\n                   E-mail: glenn@cysols.com\n       Working Group E-mail: ietf-madman@innosoft.com\n               To subscribe: ietf-madman-request@innosoft.com')
if mibBuilder.loadTexts: dsMIB.setDescription(' The MIB module for monitoring Directory Services.')
dsTable = MibTable((1, 3, 6, 1, 2, 1, 66, 1), )
if mibBuilder.loadTexts: dsTable.setDescription(' The table holding information related to the Directory\n            Servers.')
dsTableEntry = MibTableRow((1, 3, 6, 1, 2, 1, 66, 1, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"))
if mibBuilder.loadTexts: dsTableEntry.setDescription(' Entry containing summary description for a Directory\n            Server.')
dsServerType = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 1), Bits().clone(namedValues=NamedValues(("frontEndDirectoryServer", 0), ("backEndDirectoryServer", 1),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsServerType.setDescription('This object indicates whether the server is\n           a frontend or, a backend or, both. If the server\n           is a frontend, then the frontEndDirectoryServer\n           bit will be set. Similarly for the backend.')
dsServerDescription = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 2), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsServerDescription.setDescription('A text description of the application.  This information\n          is intended to identify and briefly describe the\n          application in a status display.')
dsMasterEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 3), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsMasterEntries.setDescription(' Number of entries mastered in the Directory Server.')
dsCopyEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 4), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsCopyEntries.setDescription(' Number of entries for which systematic (slave)\n            copies are maintained in the Directory Server.')
dsCacheEntries = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 5), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsCacheEntries.setDescription(' Number of entries cached (non-systematic copies) in\n            the Directory Server. This will include the entries that\n            are cached partially. The negative cache is not counted.')
dsCacheHits = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsCacheHits.setDescription(' Number of operations that were serviced from\n            the locally held cache.')
dsSlaveHits = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsSlaveHits.setDescription(' Number of operations that were serviced from\n            the locally held object replications ( copy-\n            entries).')
dsApplIfOpsTable = MibTable((1, 3, 6, 1, 2, 1, 66, 2), )
if mibBuilder.loadTexts: dsApplIfOpsTable.setDescription(' The table holding information related to the\n            Directory Server operations.')
dsApplIfOpsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 66, 2, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "DIRECTORY-SERVER-MIB", "dsApplIfProtocolIndex"))
if mibBuilder.loadTexts: dsApplIfOpsEntry.setDescription(' Entry containing operations related statistics\n            for a Directory Server.')
dsApplIfProtocolIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfProtocolIndex.setDescription('An index to uniquely identify an entry corresponding to a\n          application-layer protocol interface. This index is used\n          for lexicographic ordering of the table.')
dsApplIfProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 2), ObjectIdentifier()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfProtocol.setDescription("An identification of the protocol being used by the application\n          on this interface.  For an OSI Application, this will be the\n          Application Context.  For Internet applications, the IANA\n          maintains a registry[22] of the OIDs which correspond to\n          well-known applications.  If the application protocol is\n          not listed in the registry, an OID value of the form\n          {applTCPProtoID port} or {applUDProtoID port} are used for\n          TCP-based and UDP-based protocols, respectively. In either\n          case 'port' corresponds to the primary port number being\n          used by the protocol. The OIDs applTCPProtoID and\n          applUDPProtoID are defined in NETWORK-SERVICES-MIB")
dsApplIfUnauthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfUnauthBinds.setDescription(' Number of unauthenticated/anonymous bind requests\n            received.')
dsApplIfSimpleAuthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfSimpleAuthBinds.setDescription(' Number of bind requests that were authenticated\n            using simple authentication procedures like password\n            checks. This includes the\n            password authentication using SASL mechanisms like\n            CRAM-MD5.')
dsApplIfStrongAuthBinds = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfStrongAuthBinds.setDescription(' Number of bind requests that were authenticated\n            using TLS and X.500 strong authentication procedures.\n            This includes the binds that were\n            authenticated using external authentication procedures.')
dsApplIfBindSecurityErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfBindSecurityErrors.setDescription(' Number of bind requests that have been rejected\n            due to inappropriate authentication or\n            invalid credentials.')
dsApplIfInOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfInOps.setDescription(' Number of requests received from DUAs or other\n            Directory Servers.')
dsApplIfReadOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReadOps.setDescription(' Number of read requests  received.')
dsApplIfCompareOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfCompareOps.setDescription(' Number of compare requests received.')
dsApplIfAddEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfAddEntryOps.setDescription(' Number of addEntry requests received.')
dsApplIfRemoveEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfRemoveEntryOps.setDescription(' Number of removeEntry requests received.')
dsApplIfModifyEntryOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfModifyEntryOps.setDescription(' Number of modifyEntry requests received.')
dsApplIfModifyRDNOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfModifyRDNOps.setDescription(' Number of modifyRDN requests received.')
dsApplIfListOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfListOps.setDescription(' Number of list requests received.')
dsApplIfSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfSearchOps.setDescription(' Number of search requests- baseObject searches,\n            oneLevel searches and  whole subtree searches,\n            received.')
dsApplIfOneLevelSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfOneLevelSearchOps.setDescription(' Number of oneLevel search requests received.')
dsApplIfWholeSubtreeSearchOps = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfWholeSubtreeSearchOps.setDescription(' Number of whole subtree search requests received.')
dsApplIfReferrals = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 18), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReferrals.setDescription(' Number of referrals returned in response\n            to requests for operations.')
dsApplIfChainings = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 19), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfChainings.setDescription(' Number of operations forwarded by this Directory Server\n            to other Directory Servers.')
dsApplIfSecurityErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 20), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfSecurityErrors.setDescription(' Number of requests received\n            which did not meet the security requirements. ')
dsApplIfErrors = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 21), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfErrors.setDescription(' Number of requests that could not be serviced\n            due to errors other than security errors, and\n            referrals.\n            A partially serviced operation will not be counted\n            as an error.\n            The errors include naming-related, update-related,\n            attribute-related and service-related errors.')
dsApplIfReplicationUpdatesIn = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 22), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReplicationUpdatesIn.setDescription(' Number of replication updates fetched or received from\n            supplier Directory Servers.')
dsApplIfReplicationUpdatesOut = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 23), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfReplicationUpdatesOut.setDescription(' Number of replication updates sent to or taken by\n            consumer Directory Servers.')
dsApplIfInBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 24), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfInBytes.setDescription(' Incoming traffic, in bytes, on the interface.\n            This will include requests from DUAs as well\n            as responses from other Directory Servers.')
dsApplIfOutBytes = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 2, 1, 25), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsApplIfOutBytes.setDescription(' Outgoing traffic in bytes on the interface.\n            This will include responses to DUAs and Directory\n            Servers as well as requests to other Directory Servers.')
dsIntTable = MibTable((1, 3, 6, 1, 2, 1, 66, 3), )
if mibBuilder.loadTexts: dsIntTable.setDescription(' Each row of this table contains some details\n            related to the history of the interaction\n            of the monitored Directory Server with its\n            peer Directory Servers.')
dsIntEntry = MibTableRow((1, 3, 6, 1, 2, 1, 66, 3, 1), ).setIndexNames((0, "NETWORK-SERVICES-MIB", "applIndex"), (0, "DIRECTORY-SERVER-MIB", "dsIntEntIndex"), (0, "DIRECTORY-SERVER-MIB", "dsApplIfProtocolIndex"))
if mibBuilder.loadTexts: dsIntEntry.setDescription(' Entry containing interaction details of a Directory\n            Server with a peer Directory Server.')
dsIntEntIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: dsIntEntIndex.setDescription(' Together with applIndex and dsApplIfProtocolIndex, this\n            object forms the unique key to\n            identify the conceptual row which contains useful info\n            on the (attempted) interaction between the Directory\n            Server (referred to by applIndex) and a peer Directory\n            Server using a particular protocol.')
dsIntEntDirectoryName = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 2), DistinguishedName()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntDirectoryName.setDescription(' Distinguished Name of the peer Directory Server to\n            which this entry pertains.')
dsIntEntTimeOfCreation = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntTimeOfCreation.setDescription(' The value of sysUpTime when this row was created.\n            If the entry was created before the network management\n            subsystem was initialized, this object will contain\n            a value of zero.')
dsIntEntTimeOfLastAttempt = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 4), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntTimeOfLastAttempt.setDescription(' The value of sysUpTime when the last attempt was made\n            to contact the peer Directory Server. If the last attempt\n            was made before the network management subsystem was\n            initialized, this object will contain a value of zero.')
dsIntEntTimeOfLastSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 5), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntTimeOfLastSuccess.setDescription(' The value of sysUpTime when the last attempt made to\n            contact the peer Directory Server was successful. If there\n            have been no successful attempts this entry will have a value\n            of zero. If the last successful attempt was made before\n            the network management subsystem was initialized, this\n            object will contain a value of zero.')
dsIntEntFailuresSinceLastSuccess = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 6), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntFailuresSinceLastSuccess.setDescription(' The number of failures since the last time an\n            attempt to contact the peer Directory Server was successful.\n            If there have been no successful attempts, this counter\n            will contain the number of failures since this entry\n            was created.')
dsIntEntFailures = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 7), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntFailures.setDescription(' Cumulative failures in contacting the peer Directory Server\n            since the creation of this entry.')
dsIntEntSuccesses = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 8), ZeroBasedCounter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntSuccesses.setDescription(' Cumulative successes in contacting the peer Directory Server\n            since the creation of this entry.')
dsIntEntURL = MibTableColumn((1, 3, 6, 1, 2, 1, 66, 3, 1, 9), URLString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsIntEntURL.setDescription(' URL of the peer Directory Server.')
dsConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 66, 4))
dsGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 66, 4, 1))
dsCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 66, 4, 2))
dsEntryCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 1)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"),))
if mibBuilder.loadTexts: dsEntryCompliance.setDescription('The compliance statement for SNMP entities\n                which implement the DIRECTORY-SERVER-MIB for\n                a summary overview of the Directory Servers .')
dsOpsCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 2)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"), ("DIRECTORY-SERVER-MIB", "dsOpsGroup"),))
if mibBuilder.loadTexts: dsOpsCompliance.setDescription('The compliance statement for SNMP entities\n                which implement the DIRECTORY-SERVER-MIB for monitoring\n                Directory Server operations,  entry statistics and cache\n                performance.')
dsIntCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 3)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"), ("DIRECTORY-SERVER-MIB", "dsIntGroup"),))
if mibBuilder.loadTexts: dsIntCompliance.setDescription(' The compliance statement  for SNMP  entities\n                     which implement the DIRECTORY-SERVER-MIB for\n                     monitoring Directory Server operations and the\n                     interaction of the Directory Server with peer\n                     Directory Servers.')
dsOpsIntCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 66, 4, 2, 4)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsEntryGroup"), ("DIRECTORY-SERVER-MIB", "dsOpsGroup"), ("DIRECTORY-SERVER-MIB", "dsIntGroup"),))
if mibBuilder.loadTexts: dsOpsIntCompliance.setDescription(' The compliance statement  for SNMP  entities\n                  which implement the DIRECTORY-SERVER-MIB for monitoring\n                  Directory Server operations and the interaction of the\n                  Directory Server with peer Directory Servers.')
dsEntryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 66, 4, 1, 1)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsServerType"), ("DIRECTORY-SERVER-MIB", "dsServerDescription"), ("DIRECTORY-SERVER-MIB", "dsMasterEntries"), ("DIRECTORY-SERVER-MIB", "dsCopyEntries"), ("DIRECTORY-SERVER-MIB", "dsCacheEntries"), ("DIRECTORY-SERVER-MIB", "dsCacheHits"), ("DIRECTORY-SERVER-MIB", "dsSlaveHits"),))
if mibBuilder.loadTexts: dsEntryGroup.setDescription(' A collection of objects for a summary overview of the\n                  Directory Servers.')
dsOpsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 66, 4, 1, 2)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsApplIfProtocolIndex"), ("DIRECTORY-SERVER-MIB", "dsApplIfProtocol"), ("DIRECTORY-SERVER-MIB", "dsApplIfUnauthBinds"), ("DIRECTORY-SERVER-MIB", "dsApplIfSimpleAuthBinds"), ("DIRECTORY-SERVER-MIB", "dsApplIfStrongAuthBinds"), ("DIRECTORY-SERVER-MIB", "dsApplIfBindSecurityErrors"), ("DIRECTORY-SERVER-MIB", "dsApplIfInOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfReadOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfCompareOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfAddEntryOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfRemoveEntryOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfModifyEntryOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfModifyRDNOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfListOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfSearchOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfOneLevelSearchOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfWholeSubtreeSearchOps"), ("DIRECTORY-SERVER-MIB", "dsApplIfReferrals"), ("DIRECTORY-SERVER-MIB", "dsApplIfChainings"), ("DIRECTORY-SERVER-MIB", "dsApplIfSecurityErrors"), ("DIRECTORY-SERVER-MIB", "dsApplIfErrors"), ("DIRECTORY-SERVER-MIB", "dsApplIfReplicationUpdatesIn"), ("DIRECTORY-SERVER-MIB", "dsApplIfReplicationUpdatesOut"), ("DIRECTORY-SERVER-MIB", "dsApplIfInBytes"), ("DIRECTORY-SERVER-MIB", "dsApplIfOutBytes"),))
if mibBuilder.loadTexts: dsOpsGroup.setDescription(' A collection of objects for monitoring the Directory\n                  Server operations.')
dsIntGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 66, 4, 1, 3)).setObjects(*(("DIRECTORY-SERVER-MIB", "dsIntEntDirectoryName"), ("DIRECTORY-SERVER-MIB", "dsIntEntTimeOfCreation"), ("DIRECTORY-SERVER-MIB", "dsIntEntTimeOfLastAttempt"), ("DIRECTORY-SERVER-MIB", "dsIntEntTimeOfLastSuccess"), ("DIRECTORY-SERVER-MIB", "dsIntEntFailuresSinceLastSuccess"), ("DIRECTORY-SERVER-MIB", "dsIntEntFailures"), ("DIRECTORY-SERVER-MIB", "dsIntEntSuccesses"), ("DIRECTORY-SERVER-MIB", "dsIntEntURL"),))
if mibBuilder.loadTexts: dsIntGroup.setDescription(" A collection of objects for monitoring the Directory\n                  Server's interaction with peer Directory Servers.")
mibBuilder.exportSymbols("DIRECTORY-SERVER-MIB", dsApplIfReferrals=dsApplIfReferrals, dsConformance=dsConformance, dsIntTable=dsIntTable, dsApplIfInBytes=dsApplIfInBytes, dsTable=dsTable, dsApplIfChainings=dsApplIfChainings, dsApplIfStrongAuthBinds=dsApplIfStrongAuthBinds, dsServerType=dsServerType, dsIntEntry=dsIntEntry, dsIntEntIndex=dsIntEntIndex, dsApplIfReadOps=dsApplIfReadOps, dsSlaveHits=dsSlaveHits, dsApplIfModifyRDNOps=dsApplIfModifyRDNOps, dsApplIfSearchOps=dsApplIfSearchOps, dsIntEntTimeOfCreation=dsIntEntTimeOfCreation, dsTableEntry=dsTableEntry, dsIntEntTimeOfLastAttempt=dsIntEntTimeOfLastAttempt, dsApplIfOneLevelSearchOps=dsApplIfOneLevelSearchOps, dsServerDescription=dsServerDescription, PYSNMP_MODULE_ID=dsMIB, dsIntEntURL=dsIntEntURL, dsApplIfSimpleAuthBinds=dsApplIfSimpleAuthBinds, dsIntEntFailuresSinceLastSuccess=dsIntEntFailuresSinceLastSuccess, dsApplIfAddEntryOps=dsApplIfAddEntryOps, dsApplIfOpsEntry=dsApplIfOpsEntry, dsApplIfSecurityErrors=dsApplIfSecurityErrors, dsEntryGroup=dsEntryGroup, dsCopyEntries=dsCopyEntries, dsOpsIntCompliance=dsOpsIntCompliance, dsApplIfReplicationUpdatesIn=dsApplIfReplicationUpdatesIn, dsOpsCompliance=dsOpsCompliance, dsCacheEntries=dsCacheEntries, dsIntEntDirectoryName=dsIntEntDirectoryName, dsApplIfListOps=dsApplIfListOps, dsApplIfUnauthBinds=dsApplIfUnauthBinds, dsIntGroup=dsIntGroup, dsApplIfOpsTable=dsApplIfOpsTable, dsApplIfErrors=dsApplIfErrors, dsOpsGroup=dsOpsGroup, dsIntCompliance=dsIntCompliance, dsApplIfProtocol=dsApplIfProtocol, dsApplIfProtocolIndex=dsApplIfProtocolIndex, dsCacheHits=dsCacheHits, dsApplIfRemoveEntryOps=dsApplIfRemoveEntryOps, dsApplIfCompareOps=dsApplIfCompareOps, dsApplIfWholeSubtreeSearchOps=dsApplIfWholeSubtreeSearchOps, dsApplIfModifyEntryOps=dsApplIfModifyEntryOps, dsIntEntFailures=dsIntEntFailures, dsIntEntSuccesses=dsIntEntSuccesses, dsGroups=dsGroups, dsApplIfInOps=dsApplIfInOps, dsApplIfReplicationUpdatesOut=dsApplIfReplicationUpdatesOut, dsIntEntTimeOfLastSuccess=dsIntEntTimeOfLastSuccess, dsCompliances=dsCompliances, dsEntryCompliance=dsEntryCompliance, dsMIB=dsMIB, dsApplIfBindSecurityErrors=dsApplIfBindSecurityErrors, dsMasterEntries=dsMasterEntries, dsApplIfOutBytes=dsApplIfOutBytes)
